==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/bathyscaph/dialogs_es.lua <==

dialogId("bat-m-tohle", "font_small", "So this is an exploratory bathyscaph.")
dialogStr("Así que este es un batiscafo exploratorio.")


dialogId("bat-m-mikro", "font_small", "A nice microscope.")
dialogStr("Un lindo microscopio.")


dialogId("bat-v-zved0", "font_big", "Shouldn`t I lift this?")
dialogStr("¿No debería de levantar esto?")


dialogId("bat-v-zved1", "font_big", "Do you want me to lift this up?")
dialogStr("¿Quieres que levante esto?")


dialogId("bat-v-vyp", "font_big", "Shouldn`t I turn that off?")
dialogStr("¿No debería de apagar eso?")


dialogId("bat-v-klid", "font_big", "Now it is quiet here.")
dialogStr("Ahora está tranquilo aquí.")


dialogId("bat-m-sluch", "font_small", "We can`t get to the receiver from here.")
dialogStr("No podemos llegar al receptor desde aquí.")


dialogId("bat-s-prome0", "font_snail", "That is going to be for me...")
dialogStr("Esa va por mi...")


dialogId("bat-s-prome1", "font_snail", "That is going to be my brother...")
dialogStr("Esa va a ser por mi hermano...")


dialogId("bat-s-prome2", "font_snail", "Could you handle that call for me, please?")
dialogStr("¿Podrías tomar esa llamada por mí, por favor?")


dialogId("bat-s-snek0", "font_snail", "I hope I am not in the way here.")
dialogStr("Espero no estorbar aquí.")


dialogId("bat-s-snek1", "font_snail", "Really, I can easily crawl away. Just say the word.")
dialogStr("En realidad, puedo arrastrarme lejos fácilmente. Sólo dí la palabra.")


dialogId("bat-s-snek2", "font_snail", "I really don`t want to be an obstacle.")
dialogStr("Realmente no quiero ser un obstáculo.")


dialogId("bat-s-snek3", "font_snail", "Just tell me if you want me to move away.")
dialogStr("Sólo avísame si quieres que me mueva .")


dialogId("bat-p-0", "font_pizla", "Hello.")
dialogStr("Hola.")


dialogId("bat-p-1", "font_pizla", "Is anybody there?")
dialogStr("¿Hay alguien ahí?")


dialogId("bat-p-2", "font_pizla", "Are you there, brother?")
dialogStr("¿Estás ahí, hermano?")


dialogId("bat-p-3", "font_pizla", "The snail Escargot speaking.")
dialogStr("El caracol Snail al habla.")


dialogId("bat-p-4", "font_pizla", "I can`t hear you.")
dialogStr("No te puedo escuchar.")


dialogId("bat-p-5", "font_pizla", "Hello, hello!")
dialogStr("¡Hola, hola!")


dialogId("bat-p-zhov0", "font_statue", "Hello, chief inspector Clouseau speaking. I am looking for the dangerous shellfish, who... Oh no, not now, Kato, you yellow ape!")
dialogStr("Hola, Jefe Inspector Clouseau al habla. Estoy buscando al peligroso crustáceo, que... Oh no, no ahora, Kato, ¡maldito mono amarillo!")


dialogId("bat-p-zhov1", "font_green", "Hello, you have reached the number 4202-21913271. Nobody from the family of Roundfish is presently present. Please, leave the message after the beep. What happened?")
dialogStr("Hola, usted ha discado el número 4202-21913271. Nadie de la familia PezCuadrado está aquí ahora. Por favor, deje el mensaje después del beep. ¿Qué ocurrió?")

==> fillets-ng-data_1.0.0.orig.tar.gz: fillets-ng-data-1.0.0/script/bathyscaph/dialogs_es.lua <==

dialogId("bat-m-tohle", "font_small", "So this is an exploratory bathyscaph.")
dialogStr("Así que este es un batiscafo exploratorio.")


dialogId("bat-m-mikro", "font_small", "A nice microscope.")
dialogStr("Un lindo microscopio.")


dialogId("bat-v-zved0", "font_big", "Shouldn’t I lift this?")
dialogStr("¿No debería de levantar esto?")


dialogId("bat-v-zved1", "font_big", "Do you want me to lift this up?")
dialogStr("¿Quieres que levante esto?")


dialogId("bat-v-vyp", "font_big", "Shouldn’t I turn that off?")
dialogStr("¿No debería de apagar eso?")


dialogId("bat-v-klid", "font_big", "Now it is quiet here.")
dialogStr("Ahora está tranquilo aquí.")


dialogId("bat-m-sluch", "font_small", "We can’t get to the receiver from here.")
dialogStr("No podemos llegar al receptor desde aquí.")


dialogId("bat-s-prome0", "font_snail", "That is going to be for me...")
dialogStr("Esa va por mi...")


dialogId("bat-s-prome1", "font_snail", "That is going to be my brother...")
dialogStr("Esa va a ser por mi hermano...")


dialogId("bat-s-prome2", "font_snail", "Could you handle that call for me, please?")
dialogStr("¿Podrías tomar esa llamada por mí, por favor?")


dialogId("bat-s-snek0", "font_snail", "I hope I am not in the way here.")
dialogStr("Espero no estorbar aquí.")


dialogId("bat-s-snek1", "font_snail", "Really, I can easily crawl away. Just say the word.")
dialogStr("En realidad, puedo arrastrarme lejos fácilmente. Sólo dí la palabra.")


dialogId("bat-s-snek2", "font_snail", "I really don’t want to be an obstacle.")
dialogStr("Realmente no quiero ser un obstáculo.")


dialogId("bat-s-snek3", "font_snail", "Just tell me if you want me to move away.")
dialogStr("Sólo avísame si quieres que me mueva .")


dialogId("bat-p-0", "font_pizla", "Hello.")
dialogStr("Hola.")


dialogId("bat-p-1", "font_pizla", "Is anybody there?")
dialogStr("¿Hay alguien ahí?")


dialogId("bat-p-2", "font_pizla", "Are you there, brother?")
dialogStr("¿Estás ahí, hermano?")


dialogId("bat-p-3", "font_pizla", "The snail Escargot speaking.")
dialogStr("El caracol Snail al habla.")


dialogId("bat-p-4", "font_pizla", "I can’t hear you.")
dialogStr("No te puedo escuchar.")


dialogId("bat-p-5", "font_pizla", "Hello, hello!")
dialogStr("¡Hola, hola!")


dialogId("bat-p-zhov0", "font_statue", "Hello, chief inspector Clouseau speaking. I am looking for the dangerous shellfish, who... Oh no, not now, Kato, you yellow ape!")
dialogStr("Hola, Jefe Inspector Clouseau al habla. Estoy buscando al peligroso crustáceo, que... Oh no, no ahora, Kato, ¡maldito mono amarillo!")


dialogId("bat-p-zhov1", "font_green", "Hello, you have reached the number 4202-21913271. Nobody from the family of Roundfish is presently present. Please, leave the message after the beep. What happened?")
dialogStr("Hola, usted ha discado el número 4202-21913271. Nadie de la familia PezCuadrado está aquí ahora. Por favor, deje el mensaje después del beep. ¿Qué ocurrió?")
